import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: 路由配置项
 *
 * hidden: true                   // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true               // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect           // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    noCache: true                // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'               // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'             // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false            // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'   // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: (resolve) => require(['@/views/redirect'], resolve)
      }
    ]
  },
  {
    path: '/homePage',
    component: (resolve) => require(['@/views/homePage'], resolve),
    hidden: true
  },
  {
    path: '/login',
    component: (resolve) => require(['@/views/login'], resolve),
    hidden: true
  },
  {
    path: '/register',
    component: (resolve) => require(['@/views/register'], resolve),
    hidden: true
  },
  {
    path: '/404',
    component: (resolve) => require(['@/views/error/404'], resolve),
    hidden: true
  },
  {
    path: '/401',
    component: (resolve) => require(['@/views/error/401'], resolve),
    hidden: true
  },
  {
    path: '/skip',
    component: (resolve) => require(['@/views/skip'], resolve),
    hidden: true
  },
  {
    path: '',
    component: Layout,
    redirect: 'index',
    children: [
      {
        path: 'index',
        component: (resolve) => require(['@/views/index'], resolve),
        name: 'Index',
        meta: { title: '首页', icon: 'dashboard', affix: true }
      }
    ]
  },
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'profile',
        component: (resolve) => require(['@/views/system/user/profile/index'], resolve),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      }
    ]
  },
  {
    path: '/system/user-auth',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'role/:userId(\\d+)',
        component: (resolve) => require(['@/views/system/user/authRole'], resolve),
        name: 'AuthRole',
        meta: { title: '分配角色', activeMenu: '/system/user'}
      }
    ]
  },
  {
    path: '/system/role-auth',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'user/:roleId(\\d+)',
        component: (resolve) => require(['@/views/system/role/authUser'], resolve),
        name: 'AuthUser',
        meta: { title: '分配用户', activeMenu: '/system/role'}
      }
    ]
  },
  {
    path: '/system/dict-data',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index/:dictId(\\d+)',
        component: (resolve) => require(['@/views/system/dict/data'], resolve),
        name: 'Data',
        meta: { title: '字典数据', activeMenu: '/system/dict'}
      }
    ]
  },
  {
    path: '/monitor/job-log',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index',
        component: (resolve) => require(['@/views/monitor/job/log'], resolve),
        name: 'JobLog',
        meta: { title: '调度日志', activeMenu: '/monitor/job'}
      }
    ]
  },
  {
    path: '/tool/gen-edit',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index/:tableId(\\d+)',
        component: (resolve) => require(['@/views/tool/gen/editTable'], resolve),
        name: 'GenEdit',
        meta: { title: '修改生成配置', activeMenu: '/tool/gen'}
      }
    ]
  },
  {
    path: '/channel',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'channel/childs',
        component: (resolve) => require(['@/views/business/channel/childs'], resolve),
        name: 'ChannelChilds',
        meta: { title: '子渠道管理', activeMenu: '/channel/channel'}
      }
    ],
  },
  {
    path: '/goods',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'add',
        component: (resolve) => require(['@/views/business/goods/add'], resolve),
        name: 'GoodsAdd',
        meta: { title: '添加商品', activeMenu: '/goods/list' }
      },
      {
        path: 'edit',
        component: (resolve) => require(['@/views/business/goods/add'], resolve),
        name: 'GoodsEdit',
        meta: { title: '修改商品', activeMenu: '/goods/list', noCache: true }
      }
    ],
  },
  {
    path: '/inventory',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'detail',
        component: (resolve) => require(['@/views/business/inventory/detail'], resolve),
        name: 'InventoryDetail',
        meta: { title: '库存订单查看', activeMenu: '/goods/inventory', noCache: true }
      }
    ],
  },
  {
    path: '/exchange',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'addCode',
        component: (resolve) => require(['@/views/business/exchange/addCode'], resolve),
        name: 'ExchangeAdd',
        meta: { title: '添加兑换码', activeMenu: '/goods/exchange' }
      },
      {
        path: 'detailCode',
        component: (resolve) => require(['@/views/business/exchange/addCode'], resolve),
        name: 'ExchangeDetail',
        meta: { title: '查看兑换码', activeMenu: '/goods/exchange', noCache: true }
      }
    ],
  },
  {
    path: '/coupon',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'add',
        component: (resolve) => require(['@/views/business/coupon/add'], resolve),
        name: 'CouponAdd',
        meta: { title: '生成优惠券', activeMenu: '/coupon/list' }
      },
      {
        path: 'query',
        component: (resolve) => require(['@/views/business/coupon/add'], resolve),
        name: 'CouponQuery',
        meta: { title: '查看优惠券', activeMenu: '/coupon/list', noCache: true }
      },
      {
        path: 'edit',
        component: (resolve) => require(['@/views/business/coupon/add'], resolve),
        name: 'CouponEdit',
        meta: { title: '修改优惠券', activeMenu: '/coupon/list', noCache: true }
      },
      {
        path: 'pkg/add',
        component: (resolve) => require(['@/views/business/couponPkg/create'], resolve),
        name: 'CouponPkgAdd',
        meta: { title: '生成券包', activeMenu: '/coupon/listCouponPkg' }
      },
      {
        path: 'pkg/query',
        component: (resolve) => require(['@/views/business/couponPkg/create'], resolve),
        name: 'CouponPkgQuery',
        meta: { title: '查看券包', activeMenu: '/coupon/listCouponPkg', noCache: true }
      },
      {
        path: 'pkg/edit',
        component: (resolve) => require(['@/views/business/couponPkg/create'], resolve),
        name: 'CouponPkgEdit',
        meta: { title: '修改券包', activeMenu: '/coupon/listCouponPkg', noCache: true }
      }
    ],
  },
  {
    path: '/ticket',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'create',
        component: (resolve) => require(['@/views/business/ticket/create'], resolve),
        name: 'TicketCreate',
        meta: { title: '添加盲票组' , activeMenu: '/ticket/ticket' }
      },
      {
        path: 'edit',
        component: (resolve) => require(['@/views/business/ticket/create'], resolve),
        name: 'TicketEdit',
        meta: { title: '修改盲票组' , activeMenu: '/ticket/ticket', noCache: true }
      },
      {
        path: 'detail',
        component: (resolve) => require(['@/views/business/ticket/detail'], resolve),
        name: 'TicketDetail',
        meta: { title: '盲票组详情' , activeMenu: '/ticket/ticket', noCache: true }
      }
    ]
  },
  {
    path: '/marketing',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'add',
        component: (resolve) => require(['@/views/business/marketing/add'], resolve),
        name: 'MarketingAdd',
        meta: { title: '创建抽奖活动' , activeMenu: '/marketing/marketing' }
      },
      {
        path: 'edit',
        component: (resolve) => require(['@/views/business/marketing/add'], resolve),
        name: 'MarketingEdit',
        meta: { title: '修改抽奖活动' , activeMenu: '/marketing/marketing', noCache: true }
      },
      {
        path: 'query',
        component: (resolve) => require(['@/views/business/marketing/detail'], resolve),
        name: 'MarketingQuery',
        meta: { title: '抽奖活动详情' , activeMenu: '/marketing/marketing', noCache: true }
      }
    ]
  },
  {
    path: '/order',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'channel/query',
        component: (resolve) => require(['@/views/order/channel/detail'], resolve),
        name: 'ChannelDetail',
        meta: { title: '经销商订单查看' , activeMenu: '/order/channel', noCache: true }
      },
      {
        path: 'deliver/query',
        component: (resolve) => require(['@/views/order/deliver/detail'], resolve),
        name: 'DeliverDetail',
        meta: { title: '提货订单查看' , activeMenu: '/order/deliver', noCache: true }
      },
      {
        path: 'userTicket/query',
        component: (resolve) => require(['@/views/order/userTicket/detail'], resolve),
        name: 'UserTicketDetail',
        meta: { title: '盲票销售订单查看' , activeMenu: '/order/userTicket', noCache: true }
      },
      {
        path: 'store/query',
        component: (resolve) => require(['@/views/order/store/detail'], resolve),
        name: 'StoreDetail',
        meta: { title: '采购订单查看' , activeMenu: '/order/store', noCache: true }
      }
    ]
  },
  {
    path: '/setting',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'template/create',
        component: (resolve) => require(['@/views/setting/template/create'], resolve),
        name: 'TemplateCreate',
        meta: { title: '添加运费模板' , activeMenu: '/setting/template' }
      },
      {
        path: 'template/edit',
        component: (resolve) => require(['@/views/setting/template/create'], resolve),
        name: 'TemplateEdit',
        meta: { title: '修改运费模板' , activeMenu: '/setting/template', noCache: true }
      }
    ]
  }
]

export default new Router({
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
